#
# spec file for package libpt2
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define build_avc 1
%define build_dc 0
# Video4Linux is obsolete on Kernel 3.0, which we have after openSUSE 11.4
%define build_v4l 0%{?suse_version} <= 1140

Name:           libpt2
%define _name   ptlib
Version:        2.10.11
Release:        150600.18.9
# FIXME: when upgrading, check if the dc plugin builds with the current version of libdc1394. - Last check: 2.10.9 / 3.12.2012
%define _version 2_10_11
Summary:        Portable Windows Library from Equivalence Pty. Ltd. version 2
License:        MPL-1.0
Group:          System/Libraries
Url:            http://www.opalvoip.org/
# https://sourceforge.net/projects/opalvoip
Source:         http://download.gnome.org/sources/ptlib/2.10/%{_name}-%{version}.tar.xz
# PATCH-MISSING-TAG libpt2-fix-avc-plugin.patch jeffm@suse.com -- Fix build for avc-plugin. 
Patch1:         libpt2-fix-avc-plugin.patch 
# PATCH-FIX-UPSTREAM libpt2-aarch64.patch schwab@suse.de -- Add support for aarch64
Patch2:         libpt2-aarch64.patch
Patch3:         libpt2-ppc64le.patch
# PATCH-FIX-UPSTREAM libpt2-bison-3.0.patch sf#259 dimstar@opensuse.org -- Fix build with bison 3.0
Patch4:         libpt2-bison-3.0.patch
# PATCH-FIX-OPENSUSE libpt2-gcc5-fixes.patch dmueller@suse.com -- Fix build against GCC 5
Patch5:         libpt2-gcc5-fixes.patch
# PATCH-FIX-OPENSUSE libpt2-2.10.11-gcc6.patch dimstar@opensuse.org -- Fix build against GCC 6
Patch6:         libpt2-2.10.11-gcc6.patch
# PATCH-FIX-UPSTREAM missing-decls.patch -- Fix missing declarations
Patch7:         missing-decls.patch
# PATCH-FIX-UPSTREAM libpt2-openssl11.patch boo#1055477 mgorse@suse.com -- port to OpenSSL 1.1.
Patch8:         libpt2-openssl11.patch
BuildRequires:  SDL-devel
BuildRequires:  alsa-devel
BuildRequires:  bison
BuildRequires:  cyrus-sasl-devel
BuildRequires:  flex
BuildRequires:  gcc-c++
%if %{build_avc}
BuildRequires:  libavc1394-devel
%endif
%if %{build_dc}
BuildRequires:  libdc1394-devel
%endif
BuildRequires:  libdv-devel
BuildRequires:  libexpat-devel
BuildRequires:  libopenssl-devel
BuildRequires:  libstdc++-devel
%if %{?build_v4l}
BuildRequires:  libv4l-devel
%endif
BuildRequires:  openldap2-devel
BuildRequires:  pkg-config
BuildRequires:  pkgconfig(libpulse)
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
This is a moderately large class library that was created many years
ago as a method to produce applications that run on both Microsoft
Windows and the X Window System.

%package -n libpt%{_version}

Summary:        Portable Windows Library from Equivalence Pty. Ltd. version 2
Group:          System/Libraries
# This used to be a subpackage
Provides:       libpt2-plugins-v4l2 = %{version}
Obsoletes:      libpt2-plugins-v4l2 < %{version}
# After openSUSE 11.4, there is no more v4l available. We obsolete it to ease upgrades
%if ! (%{build_v4l})
Obsoletes:      libpt%{_version}-plugins-v4l <= %{version}
%endif
%if ! %{build_avc}
Obsoletes:      libpt%{_version}-plugins-avc <= %{version}
%endif
%if ! %{build_dc}
Obsoletes:      libpt%{_version}-plugins-dc <= %{version}
%endif

%description -n libpt%{_version}
This is a moderately large class library that was created many years
ago as a method to produce applications that run on both Microsoft
Windows and the X Window System.

%package -n libpt-devel
Summary:        Development files for %{name} (includes headers and scripts)
Group:          Development/Libraries/C and C++
Requires:       libpt%{_version} = %{version}
Conflicts:      pwlib-devel
# libpt2-devel was last used in openSUSE 11.3
Provides:       libpt2-devel = %{version}
Obsoletes:      libpt2-devel < %{version}

%description -n libpt-devel
This package includes header files and scripts needed for developers
using the %{name} library.

%if %{build_avc}

%package -n libpt%{_version}-plugins-avc

Summary:        AVC plugin for %{name}
Group:          System/Libraries
Requires:       libpt%{_version} = %{version}
Provides:       libpt2-video-plugin
# Package name that was last used in openSUSE 11.3
Provides:       libpt2-plugins-avc = %{version}
Obsoletes:      libpt2-plugins-avc < %{version}

%description -n libpt%{_version}-plugins-avc
This plugin enables AVC (firewire control for digital video cameras)
support in %{name}.
%endif

%if %{build_dc}

%package -n libpt%{_version}-plugins-dc

Summary:        DC plugin for %{name}
Group:          System/Libraries
Requires:       libpt%{_version} = %{version}
Provides:       libpt2-video-plugin
# Package name that was last used in openSUSE 11.3
Provides:       libpt2-plugins-dc = %{version}
Obsoletes:      libpt2-plugins-dc < %{version}

%description -n libpt%{_version}-plugins-dc
This plugin enables DC control (via firewire for digital video cameras)
for %{name}.
%endif

%if %{build_v4l}

%package -n libpt%{_version}-plugins-v4l

Summary:        V4L support for %{name}
Group:          System/Libraries
Requires:       libpt%{_version} = %{version}
Provides:       libpt2-video-plugin

%description -n libpt%{_version}-plugins-v4l
This plugin enables 'video for linux' (version 1) support (e.g. for USB
cameras) for %{name}.
%endif

%package -n libpt%{_version}-plugins-pulse

Summary:        Pulseaudio support for %{name}
Group:          System/Libraries
Requires:       libpt%{_version} = %{version}
# No idea about why this provides is here. Feel free to remove it if you think
# is the best thing to do... or to add an explanation about why it is useful.
Provides:       libpt2-audio-plugin
Supplements:    libpt2
Supplements:    packageand(libpt2:pulseaudio)

%description -n libpt%{_version}-plugins-pulse
This plugin enables pulseaudio support for %{name}.

%prep
%setup -q -n %{_name}-%{version}
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1
%patch5 -p1
%patch6 -p1
%patch7 -p1
%patch8 -p1

%build
export CXXFLAGS="%optflags -fvisibility-inlines-hidden"
#CXXFLAGS and CFLAGS are mixed up in the Makefiles..
export CFLAGS="%optflags -fvisibility-inlines-hidden"
%configure \
	--enable-oss \
	--enable-pulse \
%if %{build_v4l}
	--enable-v4l \
%endif
%if %{build_avc}
	--enable-avc \
%endif
        --enable-ipv6
make %{?_smp_mflags} V=1

%install
%makeinstall
rm -f %{buildroot}%{_libdir}/libpt_s.a

%post -n libpt%{_version} -p /sbin/ldconfig

%postun -n libpt%{_version} -p /sbin/ldconfig

%files -n libpt%{_version}
%defattr(-,root,root)
%doc mpl-1.0.htm History.txt
%{_libdir}/libpt.so.2*
# We explicitly list the plugins that are shipped by default to make sure we
# don't lose any without noticing it
%dir %{_libdir}/%{_name}-%{version}
%dir %{_libdir}/%{_name}-%{version}/devices
%dir %{_libdir}/%{_name}-%{version}/devices/sound
%dir %{_libdir}/%{_name}-%{version}/devices/videoinput
%{_libdir}/%{_name}-%{version}/devices/sound/alsa_pwplugin.so
%{_libdir}/%{_name}-%{version}/devices/sound/oss_pwplugin.so
%{_libdir}/%{_name}-%{version}/devices/videoinput/v4l2_pwplugin.so

%files -n libpt-devel
%defattr(0644,root,root,0755)
%doc ReadMe.txt ReadMe_QOS.txt
%{_datadir}/ptlib/
%attr(0755, root, root) %{_datadir}/ptlib/make/ptlib-config
%{_includedir}/ptbuildopts.h
%{_includedir}/ptlib.h
%{_includedir}/ptlib/
%{_includedir}/ptclib/
%{_bindir}/ptlib-config
%{_libdir}/libpt.so
%{_libdir}/pkgconfig/ptlib.pc

%if %{build_avc}

%files -n libpt%{_version}-plugins-avc
%defattr(-,root,root)
%{_libdir}/%{_name}-%{version}/devices/videoinput/avc_pwplugin.so
%endif

%if %{build_dc}

%files -n libpt%{_version}-plugins-dc
%defattr(-,root,root)
%{_libdir}/%{_name}-%{version}/devices/videoinput/dc_pwplugin.so
%endif

%if %{build_v4l}

%files -n libpt%{_version}-plugins-v4l
%defattr(-,root,root)
%{_libdir}/%{_name}-%{version}/devices/videoinput/v4l_pwplugin.so
%endif

%files -n libpt%{_version}-plugins-pulse
%defattr(-,root,root)
%{_libdir}/%{_name}-%{version}/devices/sound/pulse_pwplugin.so

%changelog
* Wed Sep 27 2017 dimstar@opensuse.org
- Disable esd plugin (openSUSE has moved through various other
  sound daemons since esd was useful):
  + Drop esound-devel BuildRequires
  + No longer pass --enable-esd to configure
  + Drop libpt2_10_11-plugins-esd subpackage.
- Add an explicit alsa-devel BuildRequires: this uses to be pulled
  in by esound devel.
* Fri Aug 25 2017 mgorse@suse.com
- Add libpt2-openssl11.patch: port to OpenSSL 1.1 (boo#1055477).
* Mon Aug 14 2017 schwab@suse.de
- missing-decls.patch: fix missing declarations
* Tue May 24 2016 dimstar@opensuse.org
- Update to version 2.10.11:
  + Bug fixes.
- Bump _version to 2_10_11.
- Add libpt2-2.10.11-gcc6.patch: Fix build against GCC 6.x
* Wed May  6 2015 dmueller@suse.com
- add libpt2-gcc5-fixes.patch: Fix build against GCC 5.x
* Fri Jan 30 2015 crrodriguez@opensuse.org
- Build with -fvisibility-inlines-hidden, shrinks the
  exported symbol table around 50%%
* Tue Jan 20 2015 dimstar@opensuse.org
- Add libpt2-bison-3.0.patch: Fix build with bison 3.0.
* Sun Feb 16 2014 ro@suse.de
- libpt2-ppc64le.patch: Add support for ppc64le
* Sun Jun 16 2013 jengelh@inai.de
- Add explicit cyrus-sasl-devel and libopenssl-devel BuildRequires:
  They used to be pulled in by openldap-devel.
* Fri Mar 29 2013 schwab@suse.de
- libpt2-aarch64.patch: Add support for aarch64
* Tue Feb 26 2013 dimstar@opensuse.org
- Update to version 2.10.10:
  + Several fixes for H.323.
  + Fix subscribing/unsubscribing when enabling and disabling SIP
    accounts.
  + Bug fixes.
* Mon Dec  3 2012 dimstar@opensuse.org
- Update to version 2.10.9:
  + Various SIP interoperability fixes.
  + Added SIP Service-Route header support (RFC 3608).
  + Various SIP/SIMPLE presence related fixes.
  + Fixed registration to broken registrars.
  + Unregister all accounts on quit.
  + Publish offline presence on quit.
  + Refresh NAT bindings with SIP OPTIONS requests.
  + Support for DNS SRV caching.
- Pass --enable-ipv6 to configure: enable IPv6 support.
* Thu Aug 23 2012 dimstar@opensuse.org
- Update to version 2.10.7:
  + Add global flag to prevent trying to get canonical name when
    doing host lookup by name.
  + Add support for GNU/Hurd.
- Changes from version 2.10.6:
  + Add encryption (StartTLS) support for LDAP
  + Use more intuitive Pulse default device name.
  + IPv6 support for PDNS.
  + Disable IPv6 by default.
  + Various bug fixes and other code changes.
* Fri May 18 2012 zaitor@opensuse.org
- Update to 2.10.5:
  + Numours changes, please see changelogfile.
- Add new subpackage: libpt-plugins-pulse. Brings PulseAudio
  support to libpt. New BuildRequires added pkgconfig(libpulse) due
  to this.
- Enable build of avc plugin.
* Thu Apr 19 2012 jeffm@suse.de
- Update to 2.10.4:
  + Numours changes, please see changelogfile.
- Drop libpt2-2.6.7-missing_links.patch, libpt2-gcc47.patch,
  ptlib-pkg_config.patch, fixed upstream.
- Add libpt2-fix-avc-plugin
* Thu Mar 15 2012 dimstar@opensuse.org
- Add libpt2-gcc47.patch: Fix build with gcc 4.7.
* Wed Jul  6 2011 dimstar@opensuse.org
- Disable build of v4l plugin on openSUSE 12.1+, based on
  build_v4l define, we change the spec:
  + Conditionally pass --enable-v4l to configure
  + Obsolete libpt%%{_version}-plugins-v4l
  + Do not create the libpt%%{_version}-plugins-v4l subpackage.
- Stop using source services, as Factory is moving away from it.
* Thu Oct 14 2010 vuntz@opensuse.org
- Disable the build of the avc plugin, like we did for the dc
  plugin: it doesn't work with the new libraw1394. We have a
  %%build_avc define to easily switch this back, and when the build
  %%is disabled, we make libpt%%{_version} obsolete the plugin
  %%subpackage, to make sure it gets removed from install.
* Thu Oct  7 2010 reddwarf@opensuse.org
- Add libpt2-2.6.7-missing_links.patch
  + Fixes build with -Wl,--no-undefined
* Mon Oct  4 2010 vuntz@opensuse.org
- Disable the build of the dc plugin, since we're moving to the new
  libraw1394 and libdc1394, and the code is not ready for this. We
  have a %%build_dc define to easily switch this back, and when the
  build is disabled, we make libpt%%{_version} obsolete the plugin
  subpackage, to make sure it gets removed from install.
* Tue Jul 27 2010 reddwarf@opensuse.org
- Update to version 2.6.7:
  + Add bpp 16 support.
  + IPv6 fixes.
  + Fix build on Solaris.
- Changes from version 2.6.6:
  + Fixed issue when during deletion of a safe object from the last
    safe pointer, that safe pointer is again set to NULL, causing
    recursion and death.
  + Fix for FreeBSD over GlibC.
  + Fix possible crash when PTLib code accessed by thread not
    created by PTlib.
  + Compatibility with newer OpenSSL library.
  + Fixed including tab character as white space for MIME extension
    lines.
  + Fixed issue with only HighestPriority threads being boosted,
    now both HighPriority and HighestPriority threads will use the
    SCHED_RR policy and set the sched_priority field accordingly.
  + Fixed compatibility with pre 2.6.16 Linux kernels.
  + Make sure an error is set on the channel if unsupported WAV
    file format used.
  + Build fixes.
- Follow SLPP, and don't break ABI changing the soname in a way
  that anyway was wrong. This also means libpt2-devel is renamed to
  libpt-devel.
- Add pkg-config BuildRequires.
- Add ptlib-pkg_config.patch: this remove abusive link flags from
  the pkg-config file. Also remove SDL-devel, libexpat-devel,
  openldap2-devel and openssl-devel Requires from devel package.
- Drop libpt2-2.6.2.patch: nobody knew exactly what it did, so
  remove it to go back to upstream behavior.
- Drop libpt2-soname.diff: this is what was done wrong and is now
  unneede since we follow the shared library packaging policy.
- We can now remove the calls to autoreconf and aclocal thanks to
  the removed patches.
- Use %%configure macro.
- Reenable ESD support: as it could be useful for PulseAudio.
- Ship the v4l2 plugin by default instead of the v4l plugin.
- Remove static library.
* Tue Oct  6 2009 dimstar@opensuse.org
- Update to version 2.6.5:
  + Fixed base 64 encoder for strings less than 3 characters long,
  + Fixed failure to use STUN sockets with symmetric NAT
  + The absence of libv4l2 should not block V4L2 plugin
  + Changed default for AVC plug in to be disabled until someone
    fixes it.
  + remconn option need config-file option
- Clean spec file using spec-cleaner.
* Sun Jul 19 2009 dominique-obs@leuenberger.net
- Update to version 2.6.4:
  + Bugfix release.
* Tue May 19 2009 dominique-obs@leuenberger.net
- Update to version 2.6.2:
  + Bugfix release
  + Rebased patch ptlib2-2.4.2.diff to ptlib2-2.6.2.patch
* Wed Apr 29 2009 vuntz@novell.com
- Update to version 2.6.1:
  + This is a major update of ptlib/opal with the following main
    features:
  - Instant Messaging. Using several different “standards”:
    RFC4975, MSRP, T.140, SIP-IM etc etc.
  - Much improved support for SIP event handling
    (SUBSCRIBE/NOTIFY/PUBLISH) using factories so more event
    packages can be added easily.
  - Support for SIP “dialog” event package.
  - Support for Shared Line Appearance (aka Multiple Line
    Appearance, Bridged Line Appearance or Busy Lamp Field)
  - Significant improvements in IPv6 support
  - Major enhancements to the video rate controller.
  - Removal of the old H.263 ffmpeg plug in and enhancement of
    the H.263-1998 plug it to take its place.
  - H.224 support (H.323 only).
  - SBC audio codec plug in.
  - G.722 audio codec plug in.
  - CELT audio codec plug in.
  - SWIG support for use in other languages, Java first.
  - Much improved multi-platform sample GUI client, OpenPhone.
    Now standard test environment replacing simpleOPAL.
- Add libv4l-devel BuildRequires for the v4l2 plugin.
- Remove part of ptlib-2.4.2.diff which changed P_OEXPAT to
  P_EXPAT, which was breaking the expat support from ptlib when
  used by opal.
* Thu Nov  6 2008 kkeil@suse.de
- do not create include/ptbuildopts.h.in from scratch
  This caused configuration errors in ekiga (bnc#440869)
* Sun Oct 26 2008 kkeil@suse.de
- update to bugfix release 2.4.2
  * Fix static linking for mingw
  * Move the defaults so we can overwrite them depending on the
    platform
  * Finally fix static and dynamic plugins on mingw
  * Fixed being able to pass a ip%%interface form of address string
    to a PIPSocket::Address and it still works correctly, using the
    ip part if there
  * Fixed correct upper/lower case comparisons as per RFC952
  * Make vfw configurable
  * STUN was not working with Open NAT
  * Fixed incorrect port displayed in trace log for STUN
  * Make sure CreateSocketPair also works with open nat
  * Allow video file output device to work with new files
  * Fixed problem with PSafeCollection destructor deleting objects
    even if they still have a PSafePtr referencing them
  * Fix compilation without vfw
* Mon Oct 20 2008 kkeil@suse.de
- remove windows build files to avoid license issues (bnc#436929)
* Mon Oct 13 2008 kkeil@suse.de
- add version 2.4.1 needed for ekiga 3.0 (bnc#428117)
  this is the successor of pwlib, but with new API version 2
  so it does not replace pwlib yet
